@@ -5,9 +5,9 @@
 */
 
 #include "collectionpage/attributes/expirecollectionattribute.h"
-#include <Akonadi/KMime/NewMailNotifierAttribute>
+#include <Akonadi/NewMailNotifierAttribute>
 
-#include <AkonadiCore/attributefactory.h>
+#include <Akonadi/AttributeFactory>
 
 namespace
 {
