@@ -233,6 +233,7 @@ void CollectionExpiryWidget::save(const CollectionExpirySettings &collectionExpi
     attribute->setReadExpireUnits(collectionExpirySettings.mReadExpireUnits);
     attribute->setUnreadExpireUnits(collectionExpirySettings.mUnreadExpireUnits);
     attribute->setExpireAction(collectionExpirySettings.mExpireAction);
+    attribute->setExpireMessagesWithValidDate(!collectionExpirySettings.expiryMessagesWithInvalidDate);
 
     if (saveSettings) {
         auto job = new CollectionExpiryJob;
@@ -266,6 +267,19 @@ bool CollectionExpirySettings::isValid() const
     return valid;
 }
 
+void CollectionExpirySettings::convertFromExpireCollectionAttribute(const ExpireCollectionAttribute *attr)
+{
+    if (attr) {
+        attr->daysToExpire(daysToExpireUnread, daysToExpireRead);
+        expiryGloballyOn = attr->isAutoExpire();
+        mUnreadExpireUnits = attr->unreadExpireUnits();
+        mReadExpireUnits = attr->readExpireUnits();
+        mExpireAction = attr->expireAction();
+        mExpireToFolderId = attr->expireToFolderId();
+        expiryMessagesWithInvalidDate = !attr->expireMessagesWithValidDate();
+    }
+}
+
 QDebug operator<<(QDebug d, const CollectionExpirySettings &t)
 {
     d << " expiryGloballyOn " << t.expiryGloballyOn;
