@@ -1,16 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2016-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
 
+#include "mailcommon_private_export.h"
 #include <QDialog>
 class KUrlRequester;
 namespace MailCommon
 {
-class FilterActionMissingSoundUrlDialog : public QDialog
+class MAILCOMMON_TESTS_EXPORT FilterActionMissingSoundUrlDialog : public QDialog
 {
     Q_OBJECT
 public:
@@ -19,8 +20,8 @@ public:
     [[nodiscard]] QString soundUrl() const;
 
 private:
-    void readConfig();
-    void writeConfig();
+    MAILCOMMON_NO_EXPORT void readConfig();
+    MAILCOMMON_NO_EXPORT void writeConfig();
     KUrlRequester *const mUrlWidget;
 };
 }
