@@ -1,11 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2016-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
 
+#include "mailcommon_private_export.h"
 #include <QDialog>
 namespace MailTransport
 {
@@ -14,7 +15,7 @@ class TransportComboBox;
 
 namespace MailCommon
 {
-class FilterActionMissingTransportDialog : public QDialog
+class MAILCOMMON_TESTS_EXPORT FilterActionMissingTransportDialog : public QDialog
 {
     Q_OBJECT
 public:
@@ -23,8 +24,8 @@ public:
     [[nodiscard]] int selectedTransport() const;
 
 private:
-    void writeConfig();
-    void readConfig();
+    MAILCOMMON_NO_EXPORT void writeConfig();
+    MAILCOMMON_NO_EXPORT void readConfig();
     MailTransport::TransportComboBox *const mComboBoxTransport;
 };
 }
