@@ -10,7 +10,7 @@
 #include "kernel/mailkernel.h"
 #include "util/mailutil.h"
 
-#include <ItemCopyJob>
+#include <Akonadi/ItemCopyJob>
 #include <KLocalizedString>
 
 using namespace MailCommon;
@@ -50,7 +50,7 @@ QString FilterActionCopy::sieveCode() const
 {
     QString path;
     if (KernelIf->collectionModel()) {
-        path = MailCommon::Util::fullCollectionPath(mFolder);
+        path = MailCommon::Util::fullCollectionRemoveIdPath(mFolder);
     } else {
         path = QString::number(mFolder.id());
     }
@@ -67,3 +67,5 @@ QString FilterActionCopy::informationAboutNotValidAction() const
 {
     return i18n("Folder destination was not defined.");
 }
+
+#include "moc_filteractioncopy.cpp"
