@@ -7,13 +7,10 @@
 
 #pragma once
 
+#include "mailcommon_private_export.h"
 #include <QWidget>
 
-namespace Phonon
-{
-class MediaObject;
-}
-
+class QMediaPlayer;
 class QPushButton;
 class KUrlRequester;
 
@@ -22,7 +19,7 @@ namespace MailCommon
 /**
  * @short A widget to play a sound from a given URL.
  */
-class SoundTestWidget : public QWidget
+class MAILCOMMON_TESTS_EXPORT SoundTestWidget : public QWidget
 {
     Q_OBJECT
 
@@ -67,6 +64,6 @@ private:
     void slotUrlChanged(const QString &);
     KUrlRequester *const m_urlRequester;
     QPushButton *const m_playButton;
-    Phonon::MediaObject *m_player = nullptr;
+    QMediaPlayer *m_player = nullptr;
 };
 }
