@@ -5,7 +5,6 @@
  */
 
 #include "jobscheduler.h"
-#include "mailcommon_debug.h"
 using namespace MailCommon;
 
 ScheduledTask::ScheduledTask(const Akonadi::Collection &folder, bool immediate)
@@ -226,3 +225,5 @@ ScheduledJob::ScheduledJob(const Akonadi::Collection &folder, bool immediate)
 }
 
 ScheduledJob::~ScheduledJob() = default;
+
+#include "moc_jobscheduler.cpp"
